@@ -2,7 +2,7 @@
 #added the ability to rotate the entire figure 02/24/20 and to use keys
 #Added label.pos to give better control of the figures
 "radar" <- function(x,labels=NULL,keys=NULL,center=FALSE,connect=FALSE,scale=1,ncolors=31,fill=FALSE,add=FALSE,linetyp="solid", 
-       main="Radar Plot",angle=0,absolute=FALSE,show=TRUE,digits=2,cut=.2,circles=TRUE,clockwise=FALSE,delta = NULL,label.pos=NULL,position=NULL,
+       main="Radar Plot",angle=0,absolute=FALSE,show=TRUE,digits=2,cut=.2,circles=TRUE,shape=FALSE, clockwise=FALSE,delta = NULL,label.pos=NULL,position=NULL,xlim=c(-1,1),ylim=c(-1, 1),
         ...) {
 nvar <- length(x)
 lty="solid"
@@ -40,7 +40,11 @@ if(ncolors < 2) {colors <- FALSE} else {colors <- TRUE}
  angles <- (0:SEGMENTS) * 2 * pi/SEGMENTS
  unit.circle <- cbind(cos(angles), sin(angles))
 
-if(!add) { plot(unit.circle,typ="l",asp=1,axes=FALSE,xlab="",ylab="",main=main)
+if(!add) {if(shape) {nx <- SEGMENTS/nvar
+             Lx <- seq(1,SEGMENTS+1,nx)#%% SEGMENTS + 1
+              plot(unit.circle[Lx,1],unit.circle[Lx,2],axes=FALSE,xlab="",ylab="",typ="l",xlim=xlim,ylim=ylim)
+
+} else {plot(unit.circle,typ="l",asp=1,axes=FALSE,xlab="",ylab="",main=main,xlim=xlim,ylim=ylim)}
 if(circles) {lines(unit.circle*.25,typ="l",lty="dotted",col="red")
 lines(unit.circle*.5,typ="l",lty="dotted")
 lines(unit.circle*.75,typ="l",lty="dotted",col="blue")} }
@@ -53,7 +57,7 @@ if(colors) {
 
  for(c in 1:nvar) { 
   nx <- (((c-1 + angle*num.keys) %% nvar) +1 )* SEGMENTS/nvar +1
-  nx <- nx %% 48  # +1 
+  nx <- nx %% SEGMENTS  # +1 
 if(center) {x0 <- unit.circle[nx,1] * .5
             y0 <- unit.circle[nx,2] * .5
             } else {
@@ -75,12 +79,14 @@ if(center) {x0 <- unit.circle[nx,1] * .5
           lty="solid"}
           }} else {if (scaler < .5) {col="red"} else {col="blue"}
           }
+          
+
     
    lines(Lx,Ly,col=col,lty=lty,...) } else {
    lines(Lx,Ly,...)}
     if(show) {
         txt <- paste0(sprintf("%.2f",round(x[c],2)))
-       if (abs(x[c]) > cut) {text(Lx[2]*DELTA[c],Ly[2]*DELTA[c],txt)}
+       if (abs(x[c]) > cut) {text(Lx[2]*DELTA[c],Ly[2]*DELTA[c],txt,...)}
        # if (abs(x[c]) > cut) {text(Lx[2]*sign(Lx[2])*DELTA[c],Ly[2]*sign(Ly[2])*DELTA[c],txt)}
       }     
    
@@ -93,12 +99,12 @@ if(center) {x0 <- unit.circle[nx,1] * .5
  
 
 if(!show.keys) { if(position[c] ==0) {pos=NULL} else { pos=position[c]}
-          text(x1*label.pos[c],y1*label.pos[c],labels[c],pos=pos)} 
+          text(x1*label.pos[c],y1*label.pos[c],labels[c],pos=pos,...)} 
  if(show.keys) {for(c in 1:num.keys) {
     nx <- (((c-1 + angle) %% num.keys) +1 )* SEGMENTS/num.keys +1 
     x1 <- unit.circle[nx,1]
     y1 <- unit.circle[nx,2] 
-    text(x1*label.pos[nx] ,y1*label.pos[nx],labels[c])
+    text(x1*label.pos[nx] ,y1*label.pos[nx],labels[c],...)
      }
  }
  }
